@@ -43,8 +43,11 @@ class Build(threads.DeferredThread):
         # Note: If the constructor fails, no buildresult would be uploaded (and packaging would hang). Keep it simple && be sure this does not fail on 'normal' error conditions
         self.breq = breq
         self.uploader_queue = uploader_queue
-        self.sbuild = sbuild.SBuild(self.breq, ["--keyid", util.daemon().gnupg.get_first_sec_key()])
-        super().__init__(limiter=limiter, name=self.breq.bkey)
+        self.sbuild = sbuild.SBuild(self.breq, ["--keyid", daemon.get().gnupg.get_first_sec_key()])
+        super().__init__(limiter=limiter)
+
+    def __str__(self):
+        return f"{super().__str__()} ({self.breq.bkey})"
 
     def cancel(self, who):
         if self.is_alive():
@@ -54,7 +57,7 @@ class Build(threads.DeferredThread):
         if self._shutdown is config.SHUTDOWN:
             raise util.HTTPShutdown
 
-        util.daemon().events.log(events.Type.BUILDING, self.breq)
+        daemon.get().events.log(events.Type.BUILDING, self.breq)
         try:
             # Verify buildrequest
             with closing(daemon.RemotesKeyring()) as gpg:
@@ -70,7 +73,7 @@ class Build(threads.DeferredThread):
             self.sbuild.bres.cset("Internal-Error", str(util.e2http(e)))
             self.sbuild.bres.save_to(self.breq.dir_path())
 
-        util.daemon().events.log(events.Type.BUILT, self.sbuild.bres)
+        daemon.get().events.log(events.Type.BUILT, self.sbuild.bres)
         self.uploader_queue.put(self.sbuild.bres)
 
 
@@ -79,7 +82,10 @@ class Builder(threads.EventThread):
         self.limiter = queue.Queue(maxsize=max_parallel_builds)
         self.builds = {}
         self.uploader = Uploader()
-        super().__init__(subthreads=[self.uploader], name=f"{max_parallel_builds} parallel builds")
+        super().__init__(subthreads=[self.uploader])
+
+    def __str__(self):
+        return f"{super().__str__()} ({self.limiter.maxsize} parallel builds)"
 
     def queued(self):
         return sum(map(lambda b: 1 if b.is_alive() else 0, self.builds.values()))
