@@ -1,20 +1,20 @@
-import os.path
-import enum
-import queue
-import operator
+import collections
 import datetime
+import enum
+import functools
 import glob
 import json
-import threading
-import collections
-import functools
-import weakref
 import logging
-
-from mini_buildd import config, util, call, files
+import operator
+import os.path
+import queue
+import threading
+import weakref
 
 import debian.debian_support
 
+from mini_buildd import call, config, daemon, files, util
+
 LOG = logging.getLogger(__name__)
 
 
@@ -49,6 +49,12 @@ DESC = {
 
 
 class Event():
+    #: Set of "building" event types (package not (necessarily) in instance's repository)
+    BUILDING = {Type.BUILDING, Type.BUILT}
+
+    #: Set of "packaging" event types (package in instances's repository)
+    PACKAGING = set(Type) - BUILDING
+
     def __init__(self, type_, distribution, source, version, extra):
         self.type = type_
         self.distribution = distribution
@@ -115,6 +121,7 @@ class Event():
                      extra=xtra)
 
     def save_as(self, file_path):
+        os.makedirs(os.path.dirname(file_path), exist_ok=True)
         with util.fopen(file_path, "w") as f:
             json.dump(self.to_json(), f)
 
@@ -124,7 +131,7 @@ class Event():
                 try:
                     call.Call([hook, file_path]).check()
                 except BaseException as e:
-                    LOG.warning(f"Custom Event Hook failed: {hook}: {e}")
+                    LOG.warning("Custom Event Hook failed: %s: %s", hook, e)
 
     def json_file_name(self):
         return files.DebianName(self.source, self.version).json(self.type.name, self.extra["architecture"] if self.type in [Type.BUILT, Type.BUILDING] else None)
@@ -138,7 +145,7 @@ class Event():
     def ongoing(self):
         """Get ongoing status (bool) -- convenience for template access"""
         try:
-            return self.extra["bkey"] in util.daemon().events.ongoing
+            return self.extra["bkey"] in daemon.get().events.ongoing
         except Exception:
             return False
 
@@ -191,25 +198,28 @@ class Queue(collections.deque):
         if exception is None and changes.cget("Internal-Error"):
             exception = util.HTTPInternal(changes.cget("Internal-Error"))
 
+        if exception is not None:
+            util.log_exception(LOG, "Event exception", exception)
+
         event = Event.from_changes(typ, changes, exception, extra)
-        file_path = changes.events_path.join(event.json_file_name())
+        file_path = changes.get_events_path(event.json_file_name())
         event.save_as(file_path)
-        LOG.debug(f"Logging event: {event} ({file_path})")
+        LOG.debug("Logging event: %s (%s)", event, file_path)
         with self._lock:
             self.appendleft(event)
-            util.attempt(util.daemon().model.mbd_notify_event, event)
+            util.attempt(daemon.get_model().mbd_notify_event, event)
 
             for _key, (weakref_obj, q) in self._clients.items():
                 if weakref_obj() is not None:
-                    LOG.debug(f"Queuing event for object '{weakref_obj}'")
+                    LOG.debug("Queuing event for object '%s'", weakref_obj)
                     q.put(event)
 
             # Handle "ongoing" dict
             if event.type in [Type.PACKAGING, Type.BUILDING]:
-                LOG.debug(f"Adding event to 'ongoing': {changes.bkey}={event}")
+                LOG.debug("Adding event to 'ongoing': %s=%s", changes.bkey, event)
                 self.ongoing[changes.bkey] = event
             elif event.type in [Type.BUILT, Type.INSTALLED, Type.FAILED]:
-                LOG.debug(f"Deleting event from 'ongoing': {changes.bkey} from {event}")
+                LOG.debug("Deleting event from 'ongoing': %s from %s", changes.bkey, event)
                 self.ongoing.pop(changes.bkey, None)   # None: Should rather not raise exception here if key is not there for some reason
 
     def attach(self, obj, after=None):
@@ -217,13 +227,13 @@ class Queue(collections.deque):
             # Garbage collection
             for key in [key for key, (weakref_obj, _q) in self._clients.items() if weakref_obj() is None]:
                 del self._clients[key]
-                LOG.debug(f"Events queue client detached ({len(self._clients)}/{config.MAX_EVENTS_QUEUE_CLIENTS}): {obj}")
+                LOG.debug("Events queue client detached (%s/%s): %s", len(self._clients), config.MAX_EVENTS_QUEUE_CLIENTS, obj)
 
             if id(obj) not in self._clients:
                 if len(self._clients) >= config.MAX_EVENTS_QUEUE_CLIENTS:
                     raise util.HTTPUnavailable(f"Max client limit ({config.MAX_EVENTS_QUEUE_CLIENTS}) exceeded")
                 self._clients[id(obj)] = (weakref.ref(obj), queue.Queue())
-                LOG.debug(f"Events queue client attached ({len(self._clients)}/{config.MAX_EVENTS_QUEUE_CLIENTS}): {obj}")
+                LOG.debug("Events queue client attached (%s/%s): %s", len(self._clients), config.MAX_EVENTS_QUEUE_CLIENTS, obj)
 
                 # Optionally put past events
                 if after is not None:
@@ -240,7 +250,7 @@ class Queue(collections.deque):
                 try:
                     client[1].put_nowait(config.SHUTDOWN)
                 except Exception as e:
-                    LOG.warning(f"Events queue: Ignoring failure to hint shutdown to client {client[0]}: {e}")
+                    LOG.warning("Events queue: Ignoring failure to hint shutdown to client %s: %s", client[0], e)
 
     def to_json(self):
         return [event.to_json() for event in self]
@@ -254,12 +264,19 @@ class Queue(collections.deque):
         return Queue(load(maxlen=maxlen), maxlen=maxlen)
 
 
+def get(events):
+    event = events.get()
+    if event is config.SHUTDOWN:
+        raise util.HTTPShutdown
+    return event
+
+
 class Attach():
     def __init__(self, events, *args, **kwargs):
         self.events = events.attach(self, *args, **kwargs)
 
     def get(self):
-        return self.events.get()
+        return get(self.events)
 
 
 def ifilter(ievents, types=None, distribution=None, source=None, version=None, minimal_version=None, exit_on=None, fail_on=None):
