@@ -169,12 +169,12 @@ class DebianVersion(debian.debian_support.Version):
 class TemplatePackage(util.TmpDir):
     """Copies a package template into a temporary directory (under 'package/')"""
 
-    def __init__(self, template):
+    def __init__(self, template, package_version=None):
         super().__init__(prefix="template-")
         self.template = template
         self.package_dir = os.path.join(self.tmpdir, "package")
         shutil.copytree(os.path.join(config.PACKAGE_TEMPLATES, template), self.package_dir)
-        self.package_version = DebianVersion.stamp()
+        self.package_version = DebianVersion.stamp() if package_version is None else package_version
         self.package_name = None
 
     @property
@@ -193,8 +193,8 @@ class TemplatePackage(util.TmpDir):
 
 
 class KeyringPackage(TemplatePackage):
-    def __init__(self):
-        super().__init__("archive-keyring")
+    def __init__(self, **kwargs):
+        super().__init__("archive-keyring", **kwargs)
 
         self.key_id = daemon.get().gnupg.get_first_sec_key()
         LOG.debug("KeyringPackage using key: '%s'", self.key_id)
@@ -231,7 +231,7 @@ class KeyringPackage(TemplatePackage):
 
         # Generate dput-ng profile
         with util.fopen(os.path.join(self.package_dir, f"{daemon.get_model().mbd_dput_name()}.json"), "w") as f:
-            f.write(util.json_pretty(daemon.get_model().mbd_get_dputng_profile()))
+            f.write(daemon.get_model().mbd_get_dputng_profile())
 
         # Generate SSL certificate
         certs_dir = os.path.join(self.package_dir, "certs")
