@@ -1,7 +1,41 @@
-import os
+r"""
+.. attention:: **wheezy or older builds on amd64**: Re-enable linux' vsyscall
+
+  In Debian kernel packages since ``4.8.4-1~exp1``::
+
+    [ Ben Hutchings ]
+    * [amd64] Enable LEGACY_VSYSCALL_NONE instead of LEGACY_VSYSCALL_EMULATE.
+      This breaks (e)glibc 2.13 and earlier, and can be reverted using the kernel
+      parameter: vsyscall=emulate
+
+  I.e.: When running the Debian standard kernel and your mini-buildd instance needs to support ``wheezy`` or earlier, you
+  need to re-enable this (in ``/etc/default/grub``).
+
+  You may use ``local-vsyscall-emulate.cfg`` in ``examples`` (a symlink should do) for this purpose.
+
+  On any running kernel, this is a poor man's check to see if vsyscall is still enabled on your system:
+
+  .. code:: bash
+
+    grep "\[vsyscall\]" /proc/self/maps
+
+  .. seealso:: :debbug:`847154`, linux package's ``NEWS`` file.
+
+.. note:: **schroot**: Verbosely logs commands ("Running command ...") explicitly via syslog (journalctl)
+
+  schroot seems to verbosely log any executed root-user command via syslog (user/notice). This will
+  clutter journalctl's (standard) log output via unit::
+
+    journalctl --unit mini-buildd.service --follow
+
+  As a workaround, specifying the (syslog compatibility) identifier like so helps to unclutter::
+
+    journalctl --identifier mini-buildd --follow
+"""
+
 import logging
 
-from mini_buildd import util, call
+from mini_buildd import call
 
 LOG = logging.getLogger(__name__)
 
@@ -14,13 +48,13 @@ class Session():
         self.session = "session:" + call.Call([COMMAND,
                                                "--begin-session",
                                                "--chroot", self.chroot]).check().stdout.strip()
-        LOG.debug(f"{self}: Schroot session started ({self.chroot})")
+        LOG.debug("%s: Schroot session started ({self.chroot})", self)
 
     def close(self):
         """
         Close session (including retries on failure)
 
-        .. attention:: **stale schroot sessions**: 'target is busy' on session close (stale schroot sessions)
+        .. attention:: **schroot**: 'target is busy' on session close (stale schroot sessions)
 
            Occasionally, a schroot session can't be closed
            properly, leaving stale sessions around. Presumably,
@@ -28,7 +62,7 @@ class Session():
            this.
 
            This internal close does try hard to avoid this -- however,
-           if disaster strikes anyway, ``mini-buildd-schroot-cleanup``
+           if disaster strikes anyway, ``mini-buildd-cruft``
            may help to remove these stale sessions manually (i.e., as
            ``mini-buildd`` user from the shell).
         """
@@ -38,7 +72,7 @@ class Session():
                               ],
                              retry_max_tries=10,
                              retry_sleep=1)
-        LOG.debug(f"{self}: Schroot session closed ({self.chroot})")
+        LOG.debug("%s: Schroot session closed (%s)", self, self.chroot)
 
     def call(self, _call, user="root"):
         return call.Call([COMMAND,
@@ -57,25 +91,12 @@ class Session():
     def __str__(self):
         return f"{self.session}"
 
-    def check_sudo_workaround(self):
-        """
-        .. attention:: **compat** (``mini-buildd <= 1.0.4``): Fail for very old and possibly insecure chroots
-
-          mini-buildd <= 1.0.4 created chroots with a "sudo workaround" for bug
-          https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=607228.
-
-          Such chroots must be recreated, and no longer used (for security reasons).
-        """
-        has_sudo_workaround = self.call(["--directory", "/", "--", "grep", f"^{os.getenv('USER')}", "/etc/sudoers"])
-        if has_sudo_workaround.success():
-            raise util.HTTPBadRequest(f"{self}: Has sudo workaround (created with versions <= 1.0.4): Please run 'Remove' + 'PCA' on this chroot to re-create!")
-
     def update_file(self, file_path, content):
         """Write content to file"""
         self.run(["--", "/bin/sh", "-c", f"echo '{content}' >{file_path}"])
-        LOG.debug(f"{self}: Updated file '{file_path}': {content}")
+        LOG.debug("%s: Updated file '%s': %s", self, file_path, content)
 
     def set_debconf(self, key, value):
         """Set arbitrary debconf value"""
         self.run(["--", "/bin/sh", "-c", f"export DEBIAN_FRONTEND=noninteractive && echo 'set {key} {value}' | debconf-communicate"])
-        LOG.debug(f"{self}: Debconf value set: {key}={value}")
+        LOG.debug("%s: Debconf value set: %s=%s", self, key, value)
