@@ -37,8 +37,7 @@ $(function()
 		const $inputSubmit = $form.find('input[type="submit"]').first();
 		const tooltipText = $inputSubmit.attr('title') || '';
 		const tooltipHtml = tooltipText.replace(/\n/g, '<br>');
-		$inputSubmit.attr('title', '');
-		$inputText.attr('placeholder', 'Text or Pattern');
+		$inputText.attr('placeholder', 'Search for packages');
 		$inputText.addClass('show-placeholder');
 		$form.on('mouseenter', function(e)
 		                       {
@@ -46,13 +45,32 @@ $(function()
 		                       }
 		).on('mousemove', function(e)
 		                  {
-		                  	$('div.mbd-tooltip').css({top: e.clientY+28, left: e.clientX});
+		                  	left = e.clientX;
+		                  	if (window.matchMedia('(max-width: 640px)').matches)
+		                  	{
+		                  			left = 0;
+		                  	}
+		                  	else if (window.matchMedia('(max-width: 75rem)').matches)
+		                  	{
+		                  			left = $(window).width()/2;
+		                  	}
+		                  	$('div.mbd-tooltip').css({top: e.clientY+30, left: left});
 		                  }
 		).on('mouseleave', function()
 		                   {
 		                   	$('div.mbd-tooltip').hide();
 		                   });
 
+		// search progress indicator
+		$form.append('<progress id="mbd-search-progress"></progress>')
+		$form.on('submit', function()
+		                   {
+		                   	$inputText.blur();
+		                   	$form.find('span').first().css('filter', 'opacity(50%)');
+		                   	$('#mbd-search-progress').css('display', 'block');
+		                   	$('div.mbd-tooltip').remove();
+		                   });
+
 		// Back button
 		if (history.length > 1)
 		{
